package diekmann.plugin;
import java.io.File;

/**
 * berschrift:   Interface fr HTML-Format Plug-Ins
 * Beschreibung:  Jedes Plug-In muss dieses Interface implementieren.
 *                Das Plug-In wird nach der Installation im Plug-In-Verzeichnis
 *                automatisch erkannt und unter dem Namen (getMenuItemText()) im Plug-In-Men aufgefhrt
 * Copyright:     Copyright (c) 2001
 * Organisation:  Diekmann (CD) Software
 * @author        Christian Diekmann
 * @version       1.0
 */

public abstract class HTMLFormatPlugIn {

  /**
   * Versionsangabe der Plug-In Schnittstelle (zur spteren Fehler-Diagnose)
   */
  public String getSuperVersion(){
    return "1.0";
  }
/**
 * Initialisierung wird als erste Methode aufgerufen
 * @param workingDirectory Verzeichnis von dem relativ alle Arbeits-Verzeichnisse liegen (zum Speichern/Laden)
 */
  public abstract void initPlugIn(String workingDirectory, String[] allProjectFiles, String[] allOpenFiles, String[] selectedFiles);

  /**
   * Plug-Ins knnen mehr als Textverarbeitung, sie knnten z.B. alle bergabeparameter annehmen und danach als
   * eigenstndiges Programm laufen ohne HTML-Format wieder Daten zurck zu geben (z.B. ein mgliches FTP-Plug-In
   * welches die selektierten Dateien hochldt, aber HTML-Format whrend dessen nicht blockieren soll.
   * @return <code>true</code> wenn Plug-In keinen Text zurck gibt und lngere Zeit unabhngig von HTML-Format arbeitet.
   *
   */
  public abstract boolean isStandAloneProgram();

/**
 * bergibt den MenItem-Namen an HTML-Format
 */
  public abstract String getMenuItemText();

/**
 * bergibt den MenItem-Tooltip an HTML-Format
 */
  public abstract String getToolTip();

/**
 * True wenn ein Configuration Dialog vorhanden ist.
 */
  public abstract boolean isConfigurationDialogExists();

/**
 * True wenn ein Auswertungs-Frame vorhanden ist.
 */
  public abstract boolean isPresentationFrameExists();

/**
 * Zeigt den Dialog an und gibt bei OK true zurck
 */
  public abstract boolean showConfigurationDialog();

/**
 * Zeigt den Auswertungs-Frame an.
 */
  public abstract boolean showPresentationDialog();

/**
 * Fhrt die Textbearbeitung durch und gibt bearbeiteten Text zurck.
 * @return null wenn Text nicht gendert wurde
 */
  public abstract String work(String text, File htmlDatei);
}